slepc-3.18.0 2022-10-01
Report Typos and Errors

# STShellSetContext

Sets the context for a shell ST

### Synopsis

    #include "slepcst.h"
    PetscErrorCode STShellSetContext(ST st,void *ctx)

Logically Collective on st

### Input Parameters

| st | - the shell ST
| ctx | - the context

### Fortran Notes

To use this from Fortran you must write a Fortran interface definition for this function that tells Fortran the Fortran derived data type that you are passing in as the ctx argument.

### See Also

STShellGetContext()

### Level

advanced

### Location

src/sys/classes/st/impls/shell/shell.c

### Examples

src/eps/tutorials/ex10.c.html
src/eps/tutorials/ex35.c.html
src/eps/tutorials/ex36.c.html
Index of all ST routines
Table of Contents for all manual pages
Index of all manual pages